@@ -22,7 +22,8 @@
  */
 void BlockDestructor(const char *name, void *value, 
                      uint type, uint flags, void *param);
-BOOL ReadBlockToFile(TASK *task, HTML_MARKUP *htmlMarkup, STREAM *blockStream);
+BOOL ReadBlockToFile(TASK *task, BOOL expand, 
+                     const char *tag, STREAM *blockStream);
 BOOL ReadinBlock(TASK *task, HTML_MARKUP *htmlMarkup, STREAM *blockStream);
 
 uint BlockProcessor(TASK *task, HTML_MARKUP *htmlMarkup, char **newPlaintext);
