@@ -45,37 +45,8 @@ const char *VAR_TEMPLATE_NAME = "__!TEMPLATE FILE~";
 char htpOpenMarkup = HTML_OPEN_MARKUP;
 char htpCloseMarkup = HTML_CLOSE_MARKUP;
 
-/*
-// the global variable store ... holds permanent, file-to-file macros
-// (these are set in the global default file) ... filename kept for
-// dependency checking
-*/
-VARSTORE globalVarStore;
-char globalFilename[MAX_PATHNAME_LEN];
-
-/*
-// the "project" variable store ... holds macros only for files in current
-// directory, or project (this is loaded from the project default file,
-// which is called htp.def)
-*/
-VARSTORE projectVarStore;
-char projectFilename[MAX_PATHNAME_LEN];
-
 /*
 // include file search path
 */
 char searchPath[SEARCH_PATH_SIZE] = { 0, };
 
-/*
-// ALT text macro store
-*/
-VARSTORE altTextVarStore;
-
-/*
-// for tracking ExpandMacros performance, debug version only
-*/
-#if DEBUG
-uint expandSkipped = 0;
-uint expandPerformed = 0;
-#endif
-
