@@ -234,21 +234,24 @@ uint FileExecuteProcessor(TASK *task,
 
 #else
     /* if redirection required, create a pipe for our child process */
-    if(redirect) {
+    if (redirect) {
         pid_t pid;
         int pipefds[2];
         extern char **environ;
 
-        pipe(pipefds);
+        if (pipe(pipefds) != 0)
+        {
+            HtpMsg(MSG_ERROR, task->infile, "unable to create pipe for redirection");
+            return MARKUP_ERROR;
+        }
+
         pid = fork();
         if (pid == 0) {
             char *argv[4];
 
-            if (redirect) {
-                dup2(pipefds[1], 1);
-                close(pipefds[0]);
-                close(pipefds[1]);
-            }
+            dup2(pipefds[1], 1);
+            close(pipefds[0]);
+            close(pipefds[1]);
             
             argv[0] = "sh";
             argv[1] = "-c";
@@ -256,8 +259,9 @@ uint FileExecuteProcessor(TASK *task,
             argv[3] = NULL;
             execve("/bin/sh", argv, environ);
             exit(127);
-        } else
-            close(pipefds[1]);
+        }
+
+        close(pipefds[1]);
 
         if (pid == -1) 
             exitCode = -1;
