@@ -320,7 +320,7 @@ BOOL ProcessDefaultFile(VARSTORE *varstore, const char *file)
 
 BOOL ProcessResponseFile(VARSTORE *parentVarStore, const char *resp)
 {
-    char textline[128];
+    char textline[MAX_CMDLINE_LEN];
     char defResp[MAX_PATHNAME_LEN];
     char newDirectory[MAX_PATHNAME_LEN];
     char oldDirectory[MAX_PATHNAME_LEN];
@@ -434,7 +434,7 @@ BOOL ProcessResponseFile(VARSTORE *parentVarStore, const char *resp)
 
             /* found something ... like parsing the command-line, look for */
             /* options, then response files, then regular in and out filenames */
-            if((*ptr == '-') || (*ptr == '/'))
+            if(*ptr == '-')
             {
                 ParseToken(NULL, ptr+1);
             }
@@ -551,7 +551,7 @@ int main(int argc, char *argv[])
     /* search command-line for options */
     for(ctr = 1; ctr < (uint) argc; ctr++)
     {
-        if((*argv[ctr] == '-') || (*argv[ctr] == '/'))
+        if(*argv[ctr] == '-')
         {
             /* command-line option specified */
             ParseToken(NULL, argv[ctr]+1);
