@@ -40,7 +40,7 @@ IMAGEURL *FindImageUrl (const char *url) {
 
 BOOL ExistsImageUrl (const char *url)
 {
-    return (FindImageUrl != NULL);
+    return (FindImageUrl(url) != NULL);
 }
 
 
