@@ -25,5 +25,14 @@ BOOL OpenImageFile(const char *filename, IMAGEFILE *imageFile);
 void CloseImageFile(IMAGEFILE *imageFile);
 BOOL GetImageDimensions(IMAGEFILE *imageFile, DWORD *width, DWORD *height);
 
+
+/*
+// image url substitution
+*/
+
+BOOL ExistsImageUrl (const char *url);
+BOOL StoreImageUrl (const char *url, char* path);
+BOOL RemoveImageUrl (const char *url);
+
 #endif
 
