@@ -133,28 +133,45 @@ BOOL JpegFormatFound(FILE *file)
         return FALSE;
     }
 
-    if(JpegNextMarker(file, &marker, &size) == FALSE)
+    while(JpegNextMarker(file, &marker, &size) == TRUE)
     {
-        return FALSE;
+        /* should see an APP0 marker */
+        if(marker == M_APP0)
+        {
+            /* file format is now pointing to JFIF header */
+            /* look for the signature */
+            
+            if(fread(signature, 1, 5, file) != 5)
+            {
+                HtpMsg(MSG_WARNING, NULL, "unable to read JFIF signature from file");
+                return FALSE;
+            }
+
+            /* it all comes down to the signature being present */
+            return (strcmp(signature, "JFIF") == 0) ? TRUE : FALSE;
+        } else if(marker == 0xe1)
+        {
+            /* file format is now pointing to JFIF header */
+            /* look for the signature */
+            
+            if(fread(signature, 1, 5, file) != 5)
+            {
+                HtpMsg(MSG_WARNING, NULL, "unable to read JFIF signature from file");
+                return FALSE;
+            }
+
+            /* it all comes down to the signature being present */
+            return (strcmp(signature, "Exif") == 0) ? TRUE : FALSE;
+        } else {
+            if (fseek (file, size-2, SEEK_CUR) != 0)
+            {
+                HtpMsg(MSG_WARNING, NULL, "unable to seek past JFIF block");
+                return FALSE;
+            }
+        }
     }
-
-    /* should see an APP0 marker */
-    if(marker != M_APP0)
-    {
-        return FALSE;
-    }
-
-    /* file format is now pointing to JFIF header */
-    /* look for the signature */
-
-    if(fread(signature, 1, 5, file) != 5)
-    {
-        HtpMsg(MSG_WARNING, NULL, "unable to read JFIF signature from file");
-        return FALSE;
-    }
-
-    /* it all comes down to the signature being present */
-    return (strcmp(signature, "JFIF") == 0) ? TRUE : FALSE;
+    
+    return FALSE;
 }
 
 BOOL JpegReadDimensions(FILE *file, DWORD *height, DWORD *width)
