@@ -529,10 +529,12 @@ uint ExpandMetatag(TASK *task, HTML_MARKUP *htmlMarkup)
             attrib = htmlMarkup->attrib;
             while (attrib != NULL)
             {
-                wildcardLength += 
-                    strlen(attrib->name) + strlen(attrib->value) + 2;
-                if (attrib->quotes)
-                    wildcardLength += 2;
+                wildcardLength += strlen(attrib->name) + 1;
+                if (attrib->value) {
+                    wildcardLength += strlen(attrib->value) + 1;
+                    if (attrib->quotes)
+                        wildcardLength += 2;
+                }
                 attrib = attrib->next;
             }
 
@@ -544,16 +546,18 @@ uint ExpandMetatag(TASK *task, HTML_MARKUP *htmlMarkup)
                 ptr = wildcards;
                 while ((attrib = htmlMarkup->attrib) != NULL) {
                     ptr = stpcpy(ptr, attrib->name);
-                    *ptr++ = '=';
-                    if (attrib->quotes == QUOTES_DOUBLE)
-                        *ptr++ = '"';
-                    else if (attrib->quotes == QUOTES_SINGLE)
-                        *ptr++ = '\'';
-                    ptr = stpcpy(ptr, attrib->value);
-                    if (attrib->quotes == QUOTES_DOUBLE)
-                        *ptr++ = '"';
-                    else if (attrib->quotes == QUOTES_SINGLE)
-                        *ptr++ = '\'';
+                    if (attrib->value) {
+                        *ptr++ = '=';
+                        if (attrib->quotes == QUOTES_DOUBLE)
+                            *ptr++ = '"';
+                        else if (attrib->quotes == QUOTES_SINGLE)
+                            *ptr++ = '\'';
+                        ptr = stpcpy(ptr, attrib->value);
+                        if (attrib->quotes == QUOTES_DOUBLE)
+                            *ptr++ = '"';
+                        else if (attrib->quotes == QUOTES_SINGLE)
+                            *ptr++ = '\'';
+                    }
                     *ptr++ = ' ';
                     htmlMarkup->attrib = attrib->next;
                     DestroyAttribute(attrib);
