@@ -16,8 +16,8 @@
 
 #include "defs.h"
 
-BOOL ExpandMacrosInString(TASK *task, const char *text, char *newText,
-                          uint newTextSize, BOOL *quoted, uint *changeCount);
+BOOL ExpandMacrosInString(TASK *task, const char *text, char **newText,
+                          int *quoted, uint *changeCount);
 
 
 BOOL ExpandMacros(TASK *task, HTML_MARKUP *htmlMarkup);
@@ -27,7 +27,7 @@ BOOL ExpandMacros(TASK *task, HTML_MARKUP *htmlMarkup);
 uint ExpandMetatag(TASK *task, HTML_MARKUP *htmlMarkup);
 
 uint ExpandAll(TASK *task, HTML_MARKUP *htmlMarkup, 
-	       char** newPlaintextPtr, uint markupType);
+               char** newPlaintextPtr, uint markupType);
 
 
 #endif
