@@ -95,6 +95,11 @@
 #define HAVE_STRING_H
 #define HAVE_CTYPE_H
 #define HAVE_STDLIB_H
+#ifdef PREFER_PORTABLE_SNPRINTF
+#undef HAVE_SNPRINTF
+#define snprintf  portable_snprintf
+#define vsnprintf portable_vsnprintf
+#endif
 #ifdef HAVE_SNPRINTF
 #define HAVE_VSNPRINTF
 #define HAVE_C99_VSNPRINTF
@@ -847,6 +852,7 @@ int snprintf(char *str,size_t count,const char *fmt,...)
 
 #endif 
 
+#ifdef NEED_ASPRINTF
 #ifndef HAVE_VASPRINTF
  int vasprintf(char **ptr, const char *format, va_list ap)
 {
@@ -884,6 +890,7 @@ int snprintf(char *str,size_t count,const char *fmt,...)
 	return ret;
 }
 #endif
+#endif
 
 #ifdef TEST_SNPRINTF
 
