@@ -18,10 +18,8 @@
 typedef struct tagFILEINFO
 {
     FILE            *file;
-    uint            lineNumber;
-    uint            bytesReadThisLine;
-    uint            bytesWrittenThisLine;
     uint            pendingSpaces;
+    BOOL            emptyLine;
     WORD            flags;
 } TEXTFILE;
 
@@ -30,8 +28,7 @@ typedef struct tagFILEINFO
 */
 #define TEXTFILE_FLAG_NONE          (0)
 #define TEXTFILE_FLAG_NULL_FILE     (0x0001)
-#define TEXTFILE_FLAG_FEW_CR        (0x0002)
-#define TEXTFILE_FLAG_NO_CR         (0x0004)
+#define TEXTFILE_FLAG_FORCE_CR      (0x0002)
 
 /*
 // text file functions
@@ -43,7 +40,7 @@ void CloseFile(TEXTFILE *textFile);
 void CreateNullFile(TEXTFILE *textFile);
 
 BOOL GetFileChar(TEXTFILE *textFile, char *ch);
-BOOL PutFileChar(TEXTFILE *textFile, char ch);
+BOOL PutFileString(TEXTFILE *textFile, const char *ch);
 
 #endif
 
