@@ -28,30 +28,25 @@ uint UseProcessor(TASK *task, HTML_MARKUP *htmlMarkup, char **newPlaintext)
     VARSTORE varstore;
     VARSTORE *topVarstore;
 
-    /* check if name is present */
-    nameAttrib = UnlinkAttributeInMarkup(htmlMarkup, "NAME");
-    if (nameAttrib != NULL && nameAttrib->value != NULL) {
-
-        /* new syntax */
-        name = nameAttrib->value;
-
-    } else {
-        /* The only attribute is the macro name without value 
-         * (which can be "name" though).
-         */
-        if (nameAttrib == NULL) {
-            nameAttrib = htmlMarkup->attrib;
-            if(nameAttrib == NULL)
-            {
-                HtpMsg(MSG_ERROR, task->infile, 
-                       "USE markup without parameter", htmlMarkup->tag);
-                return MARKUP_ERROR;
-            }
-            htmlMarkup->attrib = nameAttrib->next;
+    nameAttrib = htmlMarkup->attrib;
+    if(nameAttrib == NULL)
+    {
+        HtpMsg(MSG_ERROR, task->infile, "USE markup without parameter");
+        return MARKUP_ERROR;
+    }
+    if (nameAttrib->value) {
+        if (stricmp(nameAttrib->name, "NAME") == 0) {
+            HtpMsg(MSG_WARNING, task->infile,
+                   "deprecated USE syntax, see manual");
+            name = nameAttrib->value;
+        } else {
+            HtpMsg(MSG_ERROR, task->infile, "illegal USE markup");
+            return MARKUP_ERROR;
         }
+    } else {
         name = nameAttrib->name;
     }
-
+    htmlMarkup->attrib = nameAttrib->next;
 
     /* check if the noexpand flag is present */
     noexpand = UnlinkBoolAttributeInMarkup(htmlMarkup, "NOEXPAND");
