@@ -64,7 +64,7 @@ BOOL ConditionValue(TASK *task, HTML_ATTRIBUTE *attrib, BOOL notTagFound)
                 return ERROR;
             }
             
-            condTrue = (strcmp(value, attribValue) == 0);
+            condTrue = (value != NULL && strcmp(value, attribValue) == 0);
             
             if (changed)
                 FreeMemory(attribValue);
